summaryrefslogtreecommitdiff
path: root/ext/pcre/php_pcre.c
diff options
context:
space:
mode:
authorRasmus Lerdorf <rasmus@php.net>2012-02-06 18:11:56 +0000
committerRasmus Lerdorf <rasmus@php.net>2012-02-06 18:11:56 +0000
commit704c45ec3edeab16b46fbac3b81947577d185970 (patch)
tree6c20fe7514a3244098458fc216d6c8bdfb0ad1e4 /ext/pcre/php_pcre.c
parent7dcada1c8c25a8e23d5ce3075a887f61bc8dd8a8 (diff)
downloadphp-git-704c45ec3edeab16b46fbac3b81947577d185970.tar.gz
Fix for bug 60986
Diffstat (limited to 'ext/pcre/php_pcre.c')
-rw-r--r--ext/pcre/php_pcre.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ext/pcre/php_pcre.c b/ext/pcre/php_pcre.c
index 17418435ab..fc96ef6bef 100644
--- a/ext/pcre/php_pcre.c
+++ b/ext/pcre/php_pcre.c
@@ -252,10 +252,10 @@ PHPAPI pcre_cache_entry* pcre_get_compiled_regex_cache(char *regex, int regex_le
back the compiled pattern, otherwise go on and compile it. */
if (zend_hash_find(&PCRE_G(pcre_cache), regex, regex_len+1, (void **)&pce) == SUCCESS) {
/*
* We use a quick pcre_info() check to see whether cache is corrupted, and if it
* is, we flush it and compile the pattern from scratch.
*/
- if (pcre_info(pce->re, NULL, NULL) == PCRE_ERROR_BADMAGIC) {
+ if (pcre_fullinfo(pce->re, NULL, NULL, NULL) == PCRE_ERROR_BADMAGIC) {
zend_hash_clean(&PCRE_G(pcre_cache));
} else {
#if HAVE_SETLOCALE
@@ -252,10 +252,10 @@ PHPAPI pcre_cache_entry* pcre_get_compiled_regex_cache(char *regex, int regex_le
if (zend_hash_find(&PCRE_G(pcre_cache), regex, regex_len+1, (void **)&pce) == SUCCESS) {
/*
- * We use a quick pcre_info() check to see whether cache is corrupted, and if it
+ * We use a quick pcre_fullinfo() check to see whether cache is corrupted, and if it
* is, we flush it and compile the pattern from scratch.
*/